AshFeistelCipher.Verifier.AllowNilConsistency (ash_feistel_cipher v1.0.1)
View SourceVerifies that when a from attribute allows nil, the encrypted attribute also allows nil.
This prevents potential errors where a nullable from value cannot be stored in a non-nullable encrypted attribute.