mix ash_feistel_cipher.install (ash_feistel_cipher v1.0.1)
View SourceInstalls AshFeistelCipher and FeistelCipher
Example
mix igniter.install ash_feistel_cipher
Options
--repoor-r— Specify an Ecto repo for FeistelCipher to use.--functions-prefixor-p— Specify the PostgreSQL schema prefix where the FeistelCipher functions will be created, defaults topublic--functions-saltor-s— Specify the constant value used in the Feistel cipher algorithm. A random value is generated by default if not specified. Must be between 0 and 2^31-1.